package X3D::Components::Core::ChildNode;

our $VERSION = '0.002';

use X3D::Package 'X3DChildNode : X3DNode { 
  SFNode [in,out] metadata NULL [X3DMetadataObject]
}';

1;
__END__
